#include <Key.h>
#include <Keypad.h>
#include <SPI.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#include <WiFi.h>
#include <HTTPClient.h>

#define SCREEN_WIDTH 128 // OLED width,  in pixels
#define SCREEN_HEIGHT 64 // OLED height, in pixels

// create an OLED display object connected to I2C
Adafruit_SSD1306 oled(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, -1);

// initialize WIFI setup
const char* ssid = "AndroidAP40C8";
const char* wifi_password = "kygv7147";

const byte ROWS = 4;
const byte COLS = 4;

char hexaKeys[ROWS][COLS] = {
//  {'1','2','3','A'},
//  {'4','5','6','B'},
//  {'7','8','9','C'},
//  {'*','0','#','D'}

  {0x00, 0x00,'#','*'},
  {0x00, 0x00,'0','9'},
  {'8','7','6','5'},
  {'4','3','2','1'}

//  {'#','0','*'},
//  {'9','8','7'},
//  {'6','5','4'},
//  {'3','2','1'}
};

byte rowPins[ROWS] = {16 ,4 ,0 ,2};
byte colPins[COLS] = {17, 5 ,18 ,19};   
//{17 ,5 ,18 ,19}

Keypad customKeypad = Keypad(makeKeymap(hexaKeys), rowPins, colPins, ROWS, COLS);

const String password = "7890"; // change your password here
String input_password;


void setup() {
  // put your setup code here, to run once:
  Serial.begin(9600);
  input_password.   reserve(12); // maximum input characters is 33, change if needed
  
  // initialize OLED display with I2C address 0x3C
  if (!oled.begin(SSD1306_SWITCHCAPVCC, 0x3C)) {
    Serial.println(F("failed to start SSD1306 OLED"));
    while (1);
  }

  delay(2000);         // wait two seconds for initializing
//  oled.clearDisplay(); // clear display

  oled.setTextSize(2);         // set text size
  oled.setTextColor(WHITE);    // set text color
//  oled.setCursor(0, 0);       // set position to display
//  oled.println("Password: "); // set text
//  oled.display();              // display on OLED

  //connect to WiFi
  WiFi.begin(ssid, wifi_password);
  oled.clearDisplay();  // clear display
  oled.setCursor(0, 0);       // set position to display
  oled.println("Connecting to WiFi.."); // set text
  oled.display();              // display on OLED  
  delay(10000);
  
  while (WiFi.status() != WL_CONNECTED) {
    delay(3000);
    Serial.println("Connecting to WiFi..");       

  }
  Serial.println("Connected to the WiFi network");
  oled.clearDisplay();  // clear display
  oled.setCursor(0, 0);       // set position to display
  oled.println("Connected to the WiFi network"); // set text
  oled.display();              // display on OLED
  
  delay(1000);
  
  oled.clearDisplay();
  oled.setCursor(0, 0);       // set position to display
  oled.println("Password: "); // set text
  oled.display();              // display on OLED
}


void loop() {
  if ((WiFi.status() == WL_CONNECTED)) {
    HTTPClient http;
    http.begin("https://embsmart.herokuapp.com/embedded?name=password");
    }
    
  // put your main code here, to run repeatedly:
  delay(50);
  char customKey = customKeypad.getKey();
  delay(50);  
  
  if (customKey){
    
    if (customKey == '*'){
      input_password = "";  // clear password
      Serial.println("Input password clear");
      oled.clearDisplay();  // clear display
      oled.setCursor(0, 0);       // set position to display
      oled.println("Password: "); // set text
      oled.display();              // display on OLED
    }
    else if (customKey == '#'){   // enter password
      if (password == input_password){  // password correct
        Serial.println("The password is correct!");
        oled.clearDisplay(); // clear display
        oled.setCursor(0, 0);       // set position to display
        oled.println("Correct!"); // set text
        oled.display();              // display on OLED   
 
        if(WiFi.status()== WL_CONNECTED){
          HTTPClient http;   
          http.begin("https://embsmart.herokuapp.com/embedded?name=password");
          http.addHeader("Content-Type", "application/json");            
          int httpResponseCode = http.PUT("{\"data\":1}");    
          if(httpResponseCode>0){
            int getresponse = http.GET();
            String response = http.getString();   
            Serial.println(httpResponseCode);
            Serial.println(response); 
          }
          else{
            Serial.print("Error on sending PUT Request: ");
            Serial.println(httpResponseCode);
          }
          http.end();
        }
        else{
          Serial.println("Error in WiFi connection");
        }         
      }
      else{ // password incorrect
        Serial.println("The password is incorrect!");
        oled.clearDisplay(); // clear display
        oled.setCursor(0, 0);       // set position to display
        oled.println("Incorrect!"); // set text
        oled.display();              // display on OLED

        if(WiFi.status()== WL_CONNECTED){
          HTTPClient http;   
          http.begin("https://embsmart.herokuapp.com/embedded?name=password");
          http.addHeader("Content-Type", "application/json");            
          int httpResponseCode = http.PUT("{\"data\":0}");    
          if(httpResponseCode>0){
            int getresponse = http.GET();
            String response = http.getString();   
            Serial.println(httpResponseCode);
            Serial.println(response); 
           }
          else{
            Serial.print("Error on sending PUT Request: ");
            Serial.println(httpResponseCode);
          }
          http.end();
        }
        else{
          Serial.println("Error in WiFi connection");
        }
      }

      delay(1000);
      oled.clearDisplay();  // clear display
      oled.setCursor(0, 0);       // set position to display
      oled.println("Password: "); // set text
      oled.display();              // display on OLED
      input_password = "";
    }
    else{ // append password
      input_password += customKey;
    }
    
    Serial.println(input_password);
    oled.setCursor(0, 20);       // set position to display
    oled.println(input_password); // set text
    oled.display();              // display on OLED
    

  }

}
