#include <LiquidCrystal_I2C.h>
#include <WiFi.h>
#include <Arduino_JSON.h>
#include <HTTPClient.h>
#include <AdafruitIO_Feed.h>
#include "AdafruitIO_WiFi.h"

// initialize WIFI setup
#define WIFI_SSID       "iPhoneM"
#define WIFI_PASS       "12345678"

// Adafruit IO setup
#define IO_USERNAME  "SP_TS1"
#define IO_KEY       "aio_gJTY21rmgBsXWaBTFnnxRJnbfeUm"
// set up the 'temperature' feeds
AdafruitIO_WiFi io(IO_USERNAME, IO_KEY, WIFI_SSID, WIFI_PASS);
AdafruitIO_Feed *Temp = io.feed("temp");
AdafruitIO_Feed *Light = io.feed("light");
// set the LCD number of columns and rows
int lcdColumns = 16;
int lcdRows = 2;

// set LCD address, number of columns and rows
LiquidCrystal_I2C lcd(0x27, lcdColumns, lcdRows);  

void setup(){
  Serial.begin(115200);
  delay(3000);
  
  // initialize LCD
  lcd.init();
  // turn on LCD backlight                      
  lcd.backlight();
  
  // connect WIFI
  Serial.println("Connecting to WiFi..");
  WiFi.begin(WIFI_SSID, WIFI_PASS);
  delay(3000);
  while (WiFi.status() != WL_CONNECTED) {
    delay(1500);
    Serial.println("Connecting to WiFi..");
  }
  Serial.println("Connected to the WiFi network");

  // connect to io.adafruit.com
  Serial.print("Connecting to Adafruit IO");
  io.connect();

  // wait for a connection
  while(io.status() < AIO_CONNECTED) {
    Serial.print(".");
    delay(500);
  }

  // we are connected
  Serial.println();
  Serial.println(io.statusText());
}

void loop(){
  io.run();
  
  if ((WiFi.status() == WL_CONNECTED)) {
    HTTPClient http;
    
    // Temperature Part    
    
    http.begin("https://embsmart.herokuapp.com/embedded?name=temperature");
    int httpCode = http.GET();
    if (httpCode>0){
      String payload = http.getString();
      JSONVar myObject = JSON.parse(payload);
      JSONVar mykey = myObject.keys();
      double mytemp = myObject[mykey[2]];
      Serial.println(httpCode);

      // save value to adafruit io
      Temp->save(mytemp);
      
      // print message
      lcd.setCursor(0, 0);
      lcd.print("Temp:");
      lcd.setCursor(6, 0);
      lcd.print(mytemp);
      delay(4000);
      // clears the display to print new message
      lcd.clear();
    }
    else {
      Serial.println("Error on HTTP request (in Temperature part)");
    }

    // Light Prt
   
    http.begin("https://embsmart.herokuapp.com/embedded?name=light");
    httpCode = http.GET();
    if (httpCode>0){
      String payload = http.getString();
      JSONVar myObject = JSON.parse(payload);
      JSONVar mykey = myObject.keys();
      int light = myObject[mykey[2]];
      String val = "";
      if (light == 1) {val = "ON";}
      else {val = "OFF";}
      Serial.println(httpCode);

      // save value to adafruit io
      Light->save(light);
      
      // print message
      lcd.setCursor(0, 1);
      lcd.print("Light:");
      lcd.setCursor(7, 1);
      lcd.print(val);
      delay(4000);
      // clears the display to print new message
      lcd.clear();
    }
    else {
      Serial.println("Error on HTTP request (in Light part)");
    }    

  http.end();
  }
}
